Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(933)

Unified Diff: chrome/browser/ui/webui/downloads_dom_handler.cc

Issue 10260018: Test downloads.download() disallows unsafe headers (Closed) Base URL: http://git.chromium.org/git/chromium.git@trunk
Patch Set: DownloadHidden Created 8 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/download/download_hidden.cc ('k') | chrome/chrome_browser.gypi » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/ui/webui/downloads_dom_handler.cc
diff --git a/chrome/browser/ui/webui/downloads_dom_handler.cc b/chrome/browser/ui/webui/downloads_dom_handler.cc
index 514ae7a0157fa46445cbfb804f5e7814e6292aef..02e6932124d8d3a29fdbd5366eab1f17b38542fc 100644
--- a/chrome/browser/ui/webui/downloads_dom_handler.cc
+++ b/chrome/browser/ui/webui/downloads_dom_handler.cc
@@ -212,9 +212,10 @@ void DownloadsDOMHandler::ModelChanged(content::DownloadManager* manager) {
sort(download_items_.begin(), download_items_.end(), DownloadItemSorter());
// Remove any extension downloads.
for (size_t i = 0; i < download_items_.size();) {
- if (download_crx_util::IsExtensionDownload(*download_items_[i]))
+ if (download_crx_util::IsExtensionDownload(*download_items_[i]) ||
+ DownloadHidden::Get(download_items_[i]))
download_items_.erase(download_items_.begin() + i);
else
i++;
@@ -212,9 +212,10 @@ void DownloadsDOMHandler::ModelChanged(content::DownloadManager* manager) {
sort(download_items_.begin(), download_items_.end(), DownloadItemSorter());
- // Remove any extension downloads.
+ // Remove any extension downloads and hidden downloads.
for (size_t i = 0; i < download_items_.size();) {
« no previous file with comments | « chrome/browser/download/download_hidden.cc ('k') | chrome/chrome_browser.gypi » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698